@@ -2,6 +2,7 @@ import base64
 import json
 import operator
 import re
+import shlex
 
 import sqlparse
 from sqlparse.sql import Identifier, Token, Comparison, Statement
@@ -13,8 +14,6 @@ from mlflow.protos.databricks_pb2 import INVALID_PARAMETER_VALUE
 
 import math
 
-from mlflow.store.model_registry.dbmodels.models import SqlRegisteredModel
-
 
 class SearchUtils(object):
     LIKE_OPERATOR = "LIKE"
@@ -22,13 +21,14 @@ class SearchUtils(object):
     ASC_OPERATOR = "asc"
     DESC_OPERATOR = "desc"
     VALID_ORDER_BY_TAGS = [ASC_OPERATOR, DESC_OPERATOR]
-    VALID_METRIC_COMPARATORS = set(['>', '>=', '!=', '=', '<', '<='])
-    VALID_PARAM_COMPARATORS = set(['!=', '=', LIKE_OPERATOR, ILIKE_OPERATOR])
-    VALID_TAG_COMPARATORS = set(['!=', '=', LIKE_OPERATOR, ILIKE_OPERATOR])
-    VALID_STRING_ATTRIBUTE_COMPARATORS = set(['!=', '=', LIKE_OPERATOR, ILIKE_OPERATOR])
+    VALID_METRIC_COMPARATORS = set([">", ">=", "!=", "=", "<", "<="])
+    VALID_PARAM_COMPARATORS = set(["!=", "=", LIKE_OPERATOR, ILIKE_OPERATOR])
+    VALID_TAG_COMPARATORS = set(["!=", "=", LIKE_OPERATOR, ILIKE_OPERATOR])
+    VALID_STRING_ATTRIBUTE_COMPARATORS = set(["!=", "=", LIKE_OPERATOR, ILIKE_OPERATOR])
     CASE_INSENSITIVE_STRING_COMPARISON_OPERATORS = set([LIKE_OPERATOR, ILIKE_OPERATOR])
-    VALID_REGISTERED_MODEL_SEARCH_COMPARATORS = \
-        CASE_INSENSITIVE_STRING_COMPARISON_OPERATORS.union({'='})
+    VALID_REGISTERED_MODEL_SEARCH_COMPARATORS = CASE_INSENSITIVE_STRING_COMPARISON_OPERATORS.union(
+        {"="}
+    )
     VALID_SEARCH_ATTRIBUTE_KEYS = set(RunInfo.get_searchable_attributes())
     VALID_ORDER_BY_ATTRIBUTE_KEYS = set(RunInfo.get_orderable_attributes())
     _METRIC_IDENTIFIER = "metric"
@@ -40,43 +40,44 @@ class SearchUtils(object):
     _ATTRIBUTE_IDENTIFIER = "attribute"
     _ALTERNATE_ATTRIBUTE_IDENTIFIERS = set(["attr", "attributes", "run"])
     _IDENTIFIERS = [_METRIC_IDENTIFIER, _PARAM_IDENTIFIER, _TAG_IDENTIFIER, _ATTRIBUTE_IDENTIFIER]
-    _VALID_IDENTIFIERS = set(_IDENTIFIERS
-                             + list(_ALTERNATE_METRIC_IDENTIFIERS)
-                             + list(_ALTERNATE_PARAM_IDENTIFIERS)
-                             + list(_ALTERNATE_TAG_IDENTIFIERS)
-                             + list(_ALTERNATE_ATTRIBUTE_IDENTIFIERS))
+    _VALID_IDENTIFIERS = set(
+        _IDENTIFIERS
+        + list(_ALTERNATE_METRIC_IDENTIFIERS)
+        + list(_ALTERNATE_PARAM_IDENTIFIERS)
+        + list(_ALTERNATE_TAG_IDENTIFIERS)
+        + list(_ALTERNATE_ATTRIBUTE_IDENTIFIERS)
+    )
     STRING_VALUE_TYPES = set([TokenType.Literal.String.Single])
     NUMERIC_VALUE_TYPES = set([TokenType.Literal.Number.Integer, TokenType.Literal.Number.Float])
     # Registered Models Constants
     ORDER_BY_KEY_TIMESTAMP = "timestamp"
     ORDER_BY_KEY_LAST_UPDATED_TIMESTAMP = "last_updated_timestamp"
-    ORDER_BY_KEY_MODEL_NAME = SqlRegisteredModel.name.key
-    VALID_ORDER_BY_KEYS_REGISTERED_MODELS = set([ORDER_BY_KEY_TIMESTAMP,
-                                                 ORDER_BY_KEY_LAST_UPDATED_TIMESTAMP,
-                                                 ORDER_BY_KEY_MODEL_NAME])
-    VALID_TIMESTAMP_ORDER_BY_KEYS = set([ORDER_BY_KEY_TIMESTAMP,
-                                         ORDER_BY_KEY_LAST_UPDATED_TIMESTAMP])
+    ORDER_BY_KEY_MODEL_NAME = "name"
+    VALID_ORDER_BY_KEYS_REGISTERED_MODELS = set(
+        [ORDER_BY_KEY_TIMESTAMP, ORDER_BY_KEY_LAST_UPDATED_TIMESTAMP, ORDER_BY_KEY_MODEL_NAME]
+    )
+    VALID_TIMESTAMP_ORDER_BY_KEYS = set(
+        [ORDER_BY_KEY_TIMESTAMP, ORDER_BY_KEY_LAST_UPDATED_TIMESTAMP]
+    )
     # We encourage users to use timestamp for order-by
-    RECOMMENDED_ORDER_BY_KEYS_REGISTERED_MODELS = set([ORDER_BY_KEY_MODEL_NAME,
-                                                       ORDER_BY_KEY_TIMESTAMP])
+    RECOMMENDED_ORDER_BY_KEYS_REGISTERED_MODELS = set(
+        [ORDER_BY_KEY_MODEL_NAME, ORDER_BY_KEY_TIMESTAMP]
+    )
 
     filter_ops = {
-        '>': operator.gt,
-        '>=': operator.ge,
-        '=': operator.eq,
-        '!=': operator.ne,
-        '<=': operator.le,
-        '<': operator.lt,
-        'LIKE': re.match,
-        'ILIKE': re.match
+        ">": operator.gt,
+        ">=": operator.ge,
+        "=": operator.eq,
+        "!=": operator.ne,
+        "<=": operator.le,
+        "<": operator.lt,
+        "LIKE": re.match,
+        "ILIKE": re.match,
     }
 
     @classmethod
     def get_sql_filter_ops(cls, column, operator):
-        sql_filter_ops = {
-            'LIKE': column.like,
-            'ILIKE': column.ilike
-        }
+        sql_filter_ops = {"LIKE": column.like, "ILIKE": column.ilike}
         return sql_filter_ops[operator]
 
     @classmethod
@@ -104,9 +105,12 @@ class SearchUtils(object):
         if cls._is_quoted(value, "'") or cls._is_quoted(value, '"'):
             return cls._trim_ends(value)
         elif expect_quoted_value:
-            raise MlflowException("Parameter value is either not quoted or unidentified quote "
-                                  "types used for string value %s. Use either single or double "
-                                  "quotes." % value, error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Parameter value is either not quoted or unidentified quote "
+                "types used for string value %s. Use either single or double "
+                "quotes." % value,
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         else:
             return value
 
@@ -114,9 +118,11 @@ class SearchUtils(object):
     def _valid_entity_type(cls, entity_type):
         entity_type = cls._trim_backticks(entity_type)
         if entity_type not in cls._VALID_IDENTIFIERS:
-            raise MlflowException("Invalid entity type '%s'. "
-                                  "Valid values are %s" % (entity_type, cls._IDENTIFIERS),
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid entity type '%s'. "
+                "Valid values are %s" % (entity_type, cls._IDENTIFIERS),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
 
         if entity_type in cls._ALTERNATE_PARAM_IDENTIFIERS:
             return cls._PARAM_IDENTIFIER
@@ -135,66 +141,81 @@ class SearchUtils(object):
         try:
             entity_type, key = identifier.split(".", 1)
         except ValueError:
-            raise MlflowException("Invalid identifier '%s'. Columns should be specified as "
-                                  "'attribute.<key>', 'metric.<key>', 'tag.<key>', or "
-                                  "'param.'." % identifier,
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid identifier '%s'. Columns should be specified as "
+                "'attribute.<key>', 'metric.<key>', 'tag.<key>', or "
+                "'param.'." % identifier,
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         identifier = cls._valid_entity_type(entity_type)
         key = cls._trim_backticks(cls._strip_quotes(key))
         if identifier == cls._ATTRIBUTE_IDENTIFIER and key not in valid_attributes:
-            raise MlflowException("Invalid attribute key '{}' specified. Valid keys "
-                                  " are '{}'".format(key, valid_attributes))
+            raise MlflowException(
+                "Invalid attribute key '{}' specified. Valid keys "
+                " are '{}'".format(key, valid_attributes)
+            )
         return {"type": identifier, "key": key}
 
     @classmethod
     def _get_value(cls, identifier_type, token):
         if identifier_type == cls._METRIC_IDENTIFIER:
             if token.ttype not in cls.NUMERIC_VALUE_TYPES:
-                raise MlflowException("Expected numeric value type for metric. "
-                                      "Found {}".format(token.value),
-                                      error_code=INVALID_PARAMETER_VALUE)
+                raise MlflowException(
+                    "Expected numeric value type for metric. " "Found {}".format(token.value),
+                    error_code=INVALID_PARAMETER_VALUE,
+                )
             return token.value
         elif identifier_type == cls._PARAM_IDENTIFIER or identifier_type == cls._TAG_IDENTIFIER:
             if token.ttype in cls.STRING_VALUE_TYPES or isinstance(token, Identifier):
                 return cls._strip_quotes(token.value, expect_quoted_value=True)
-            raise MlflowException("Expected a quoted string value for "
-                                  "{identifier_type} (e.g. 'my-value'). Got value "
-                                  "{value}".format(identifier_type=identifier_type,
-                                                   value=token.value),
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Expected a quoted string value for "
+                "{identifier_type} (e.g. 'my-value'). Got value "
+                "{value}".format(identifier_type=identifier_type, value=token.value),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         elif identifier_type == cls._ATTRIBUTE_IDENTIFIER:
             if token.ttype in cls.STRING_VALUE_TYPES or isinstance(token, Identifier):
                 return cls._strip_quotes(token.value, expect_quoted_value=True)
             else:
-                raise MlflowException("Expected a quoted string value for attributes. "
-                                      "Got value {value}".format(value=token.value),
-                                      error_code=INVALID_PARAMETER_VALUE)
+                raise MlflowException(
+                    "Expected a quoted string value for attributes. "
+                    "Got value {value}".format(value=token.value),
+                    error_code=INVALID_PARAMETER_VALUE,
+                )
         else:
             # Expected to be either "param" or "metric".
-            raise MlflowException("Invalid identifier type. Expected one of "
-                                  "{}.".format([cls._METRIC_IDENTIFIER, cls._PARAM_IDENTIFIER]))
+            raise MlflowException(
+                "Invalid identifier type. Expected one of "
+                "{}.".format([cls._METRIC_IDENTIFIER, cls._PARAM_IDENTIFIER])
+            )
 
     @classmethod
     def _validate_comparison(cls, tokens):
         base_error_string = "Invalid comparison clause"
         if len(tokens) != 3:
-            raise MlflowException("{}. Expected 3 tokens found {}".format(base_error_string,
-                                                                          len(tokens)),
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "{}. Expected 3 tokens found {}".format(base_error_string, len(tokens)),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         if not isinstance(tokens[0], Identifier):
-            raise MlflowException("{}. Expected 'Identifier' found '{}'".format(base_error_string,
-                                                                                str(tokens[0])),
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "{}. Expected 'Identifier' found '{}'".format(base_error_string, str(tokens[0])),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         if not isinstance(tokens[1], Token) and tokens[1].ttype != TokenType.Operator.Comparison:
-            raise MlflowException("{}. Expected comparison found '{}'".format(base_error_string,
-                                                                              str(tokens[1])),
-                                  error_code=INVALID_PARAMETER_VALUE)
-        if not isinstance(tokens[2], Token) and \
-                (tokens[2].ttype not in cls.STRING_VALUE_TYPES.union(cls.NUMERIC_VALUE_TYPES) or
-                 isinstance(tokens[2], Identifier)):
-            raise MlflowException("{}. Expected value token found '{}'".format(base_error_string,
-                                                                               str(tokens[2])),
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "{}. Expected comparison found '{}'".format(base_error_string, str(tokens[1])),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
+        if not isinstance(tokens[2], Token) and (
+            tokens[2].ttype not in cls.STRING_VALUE_TYPES.union(cls.NUMERIC_VALUE_TYPES)
+            or isinstance(tokens[2], Identifier)
+        ):
+            raise MlflowException(
+                "{}. Expected value token found '{}'".format(base_error_string, str(tokens[2])),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
 
     @classmethod
     def _get_comparison(cls, comparison):
@@ -222,8 +243,10 @@ class SearchUtils(object):
         invalids = list(filter(cls._invalid_statement_token, statement.tokens))
         if len(invalids) > 0:
             invalid_clauses = ", ".join("'%s'" % token for token in invalids)
-            raise MlflowException("Invalid clause(s) in filter string: %s" % invalid_clauses,
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid clause(s) in filter string: %s" % invalid_clauses,
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         return [cls._get_comparison(si) for si in statement.tokens if isinstance(si, Comparison)]
 
     @classmethod
@@ -233,25 +256,31 @@ class SearchUtils(object):
         try:
             parsed = sqlparse.parse(filter_string)
         except Exception:
-            raise MlflowException("Error on parsing filter '%s'" % filter_string,
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Error on parsing filter '%s'" % filter_string, error_code=INVALID_PARAMETER_VALUE
+            )
         if len(parsed) == 0 or not isinstance(parsed[0], Statement):
-            raise MlflowException("Invalid filter '%s'. Could not be parsed." %
-                                  filter_string, error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid filter '%s'. Could not be parsed." % filter_string,
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         elif len(parsed) > 1:
-            raise MlflowException("Search filter contained multiple expression '%s'. "
-                                  "Provide AND-ed expression list." % filter_string,
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Search filter contained multiple expression '%s'. "
+                "Provide AND-ed expression list." % filter_string,
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         return SearchUtils._process_statement(parsed[0])
 
     @classmethod
     def is_metric(cls, key_type, comparator):
         if key_type == cls._METRIC_IDENTIFIER:
             if comparator not in cls.VALID_METRIC_COMPARATORS:
-                raise MlflowException("Invalid comparator '%s' "
-                                      "not one of '%s" % (comparator,
-                                                          cls.VALID_METRIC_COMPARATORS),
-                                      error_code=INVALID_PARAMETER_VALUE)
+                raise MlflowException(
+                    "Invalid comparator '%s' "
+                    "not one of '%s" % (comparator, cls.VALID_METRIC_COMPARATORS),
+                    error_code=INVALID_PARAMETER_VALUE,
+                )
             return True
         return False
 
@@ -259,9 +288,11 @@ class SearchUtils(object):
     def is_param(cls, key_type, comparator):
         if key_type == cls._PARAM_IDENTIFIER:
             if comparator not in cls.VALID_PARAM_COMPARATORS:
-                raise MlflowException("Invalid comparator '%s' "
-                                      "not one of '%s'" % (comparator, cls.VALID_PARAM_COMPARATORS),
-                                      error_code=INVALID_PARAMETER_VALUE)
+                raise MlflowException(
+                    "Invalid comparator '%s' "
+                    "not one of '%s'" % (comparator, cls.VALID_PARAM_COMPARATORS),
+                    error_code=INVALID_PARAMETER_VALUE,
+                )
             return True
         return False
 
@@ -269,8 +300,10 @@ class SearchUtils(object):
     def is_tag(cls, key_type, comparator):
         if key_type == cls._TAG_IDENTIFIER:
             if comparator not in cls.VALID_TAG_COMPARATORS:
-                raise MlflowException("Invalid comparator '%s' "
-                                      "not one of '%s" % (comparator, cls.VALID_TAG_COMPARATORS))
+                raise MlflowException(
+                    "Invalid comparator '%s' "
+                    "not one of '%s" % (comparator, cls.VALID_TAG_COMPARATORS)
+                )
             return True
         return False
 
@@ -278,18 +311,19 @@ class SearchUtils(object):
     def is_attribute(cls, key_type, comparator):
         if key_type == cls._ATTRIBUTE_IDENTIFIER:
             if comparator not in cls.VALID_STRING_ATTRIBUTE_COMPARATORS:
-                raise MlflowException("Invalid comparator '{}' not one of "
-                                      "'{}".format(comparator,
-                                                   cls.VALID_STRING_ATTRIBUTE_COMPARATORS))
+                raise MlflowException(
+                    "Invalid comparator '{}' not one of "
+                    "'{}".format(comparator, cls.VALID_STRING_ATTRIBUTE_COMPARATORS)
+                )
             return True
         return False
 
     @classmethod
     def _does_run_match_clause(cls, run, sed):
-        key_type = sed.get('type')
-        key = sed.get('key')
-        value = sed.get('value')
-        comparator = sed.get('comparator').upper()
+        key_type = sed.get("type")
+        key = sed.get("key")
+        value = sed.get("value")
+        comparator = sed.get("comparator").upper()
 
         if cls.is_metric(key_type, comparator):
             lhs = run.data.metrics.get(key, None)
@@ -301,21 +335,22 @@ class SearchUtils(object):
         elif cls.is_attribute(key_type, comparator):
             lhs = getattr(run.info, key)
         else:
-            raise MlflowException("Invalid search expression type '%s'" % key_type,
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid search expression type '%s'" % key_type, error_code=INVALID_PARAMETER_VALUE
+            )
         if lhs is None:
             return False
 
         if comparator in cls.CASE_INSENSITIVE_STRING_COMPARISON_OPERATORS:
             # Change value from sql syntax to regex syntax
-            if comparator == 'ILIKE':
+            if comparator == "ILIKE":
                 value = value.lower()
                 lhs = lhs.lower()
-            if not value.startswith('%'):
-                value = '^' + value
-            if not value.endswith('%'):
-                value = value + '$'
-            value = value.replace('_', '.').replace('%', '.*')
+            if not value.startswith("%"):
+                value = "^" + value
+            if not value.endswith("%"):
+                value = value + "$"
+            value = value.replace("_", ".").replace("%", ".*")
             return cls.filter_ops.get(comparator)(value, lhs)
 
         elif comparator in cls.filter_ops.keys():
@@ -340,46 +375,53 @@ class SearchUtils(object):
         try:
             parsed = sqlparse.parse(order_by)
         except Exception:
-            raise MlflowException("Error on parsing order_by clause '{}'".format(order_by),
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Error on parsing order_by clause '{}'".format(order_by),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         if len(parsed) != 1 or not isinstance(parsed[0], Statement):
-            raise MlflowException("Invalid order_by clause '{}'. Could not be parsed."
-                                  .format(order_by),
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid order_by clause '{}'. Could not be parsed.".format(order_by),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         statement = parsed[0]
         if len(statement.tokens) == 1 and isinstance(statement[0], Identifier):
             token_value = statement.tokens[0].value
-        elif len(statement.tokens) == 1 and \
-                statement.tokens[0].match(ttype=TokenType.Keyword,
-                                          values=[cls.ORDER_BY_KEY_TIMESTAMP]):
+        elif len(statement.tokens) == 1 and statement.tokens[0].match(
+            ttype=TokenType.Keyword, values=[cls.ORDER_BY_KEY_TIMESTAMP]
+        ):
             token_value = cls.ORDER_BY_KEY_TIMESTAMP
-        elif statement.tokens[0].match(ttype=TokenType.Keyword,
-                                       values=[cls.ORDER_BY_KEY_TIMESTAMP])\
-                and all([token.is_whitespace for token in statement.tokens[1:-1]])\
-                and statement.tokens[-1].ttype == TokenType.Keyword.Order:
-            token_value = cls.ORDER_BY_KEY_TIMESTAMP + ' ' + statement.tokens[-1].value
+        elif (
+            statement.tokens[0].match(ttype=TokenType.Keyword, values=[cls.ORDER_BY_KEY_TIMESTAMP])
+            and all([token.is_whitespace for token in statement.tokens[1:-1]])
+            and statement.tokens[-1].ttype == TokenType.Keyword.Order
+        ):
+            token_value = cls.ORDER_BY_KEY_TIMESTAMP + " " + statement.tokens[-1].value
         else:
-            raise MlflowException("Invalid order_by clause '{}'. Could not be parsed."
-                                  .format(order_by),
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid order_by clause '{}'. Could not be parsed.".format(order_by),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         return token_value
 
     @classmethod
     def _parse_order_by_string(cls, order_by):
         token_value = cls._validate_order_by_and_generate_token(order_by)
         is_ascending = True
-        tokens = token_value.split()
+        tokens = shlex.split(token_value.replace("`", '"'))
         if len(tokens) > 2:
-            raise MlflowException("Invalid order_by clause '{}'. Could not be parsed."
-                                  .format(order_by),
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid order_by clause '{}'. Could not be parsed.".format(order_by),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         elif len(tokens) == 2:
             order_token = tokens[1].lower()
             if order_token not in cls.VALID_ORDER_BY_TAGS:
-                raise MlflowException("Invalid ordering key in order_by clause '{}'."
-                                      .format(order_by),
-                                      error_code=INVALID_PARAMETER_VALUE)
-            is_ascending = (order_token == cls.ASC_OPERATOR)
+                raise MlflowException(
+                    "Invalid ordering key in order_by clause '{}'.".format(order_by),
+                    error_code=INVALID_PARAMETER_VALUE,
+                )
+            is_ascending = order_token == cls.ASC_OPERATOR
             token_value = tokens[0]
         return token_value, is_ascending
 
@@ -394,11 +436,11 @@ class SearchUtils(object):
         token_value, is_ascending = cls._parse_order_by_string(order_by)
         token_value = token_value.strip()
         if token_value not in cls.VALID_ORDER_BY_KEYS_REGISTERED_MODELS:
-            raise MlflowException("Invalid order by key '{}' specified. Valid keys "
-                                  .format(token_value) +
-                                  "are '{}'"
-                                  .format(cls.RECOMMENDED_ORDER_BY_KEYS_REGISTERED_MODELS),
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid order by key '{}' specified. Valid keys ".format(token_value)
+                + "are '{}'".format(cls.RECOMMENDED_ORDER_BY_KEYS_REGISTERED_MODELS),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         return token_value, is_ascending
 
     @classmethod
@@ -414,12 +456,14 @@ class SearchUtils(object):
         elif key_type == cls._ATTRIBUTE_IDENTIFIER:
             sort_value = getattr(run.info, key)
         else:
-            raise MlflowException("Invalid order_by entity type '%s'" % key_type,
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid order_by entity type '%s'" % key_type, error_code=INVALID_PARAMETER_VALUE
+            )
 
         # Return a key such that None values are always at the end.
-        is_null_or_nan = sort_value is None or (isinstance(sort_value, float)
-                                                and math.isnan(sort_value))
+        is_null_or_nan = sort_value is None or (
+            isinstance(sort_value, float) and math.isnan(sort_value)
+        )
         if ascending:
             return (is_null_or_nan, sort_value)
         return (not is_null_or_nan, sort_value)
@@ -437,9 +481,11 @@ class SearchUtils(object):
         for order_by_clause in reversed(order_by_list):
             (key_type, key, ascending) = cls.parse_order_by_for_search_runs(order_by_clause)
             # pylint: disable=cell-var-from-loop
-            runs = sorted(runs,
-                          key=lambda run: cls._get_value_for_sort(run, key_type, key, ascending),
-                          reverse=not ascending)
+            runs = sorted(
+                runs,
+                key=lambda run: cls._get_value_for_sort(run, key_type, key, ascending),
+                reverse=not ascending,
+            )
         return runs
 
     @classmethod
@@ -453,28 +499,36 @@ class SearchUtils(object):
         try:
             decoded_token = base64.b64decode(page_token)
         except TypeError:
-            raise MlflowException("Invalid page token, could not base64-decode",
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid page token, could not base64-decode", error_code=INVALID_PARAMETER_VALUE
+            )
         except base64.binascii.Error:
-            raise MlflowException("Invalid page token, could not base64-decode",
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid page token, could not base64-decode", error_code=INVALID_PARAMETER_VALUE
+            )
 
         try:
             parsed_token = json.loads(decoded_token)
         except ValueError:
-            raise MlflowException("Invalid page token, decoded value=%s" % decoded_token,
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid page token, decoded value=%s" % decoded_token,
+                error_code=INVALID_PARAMETER_VALUE,
+            )
 
         offset_str = parsed_token.get("offset")
         if not offset_str:
-            raise MlflowException("Invalid page token, parsed value=%s" % parsed_token,
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid page token, parsed value=%s" % parsed_token,
+                error_code=INVALID_PARAMETER_VALUE,
+            )
 
         try:
             offset = int(offset_str)
         except ValueError:
-            raise MlflowException("Invalid page token, not stringable %s" % offset_str,
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid page token, not stringable %s" % offset_str,
+                error_code=INVALID_PARAMETER_VALUE,
+            )
 
         return offset
 
@@ -510,18 +564,22 @@ class SearchUtils(object):
         cls._validate_comparison(stripped_comparison)
         key = stripped_comparison[0].value
         if key not in valid_search_keys:
-            raise MlflowException("Invalid attribute key '{}' specified. Valid keys "
-                                  " are '{}'".format(key, valid_search_keys),
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid attribute key '{}' specified. Valid keys "
+                " are '{}'".format(key, valid_search_keys),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         value_token = stripped_comparison[2]
         if value_token.ttype not in cls.STRING_VALUE_TYPES:
-            raise MlflowException("Expected a quoted string value for attributes. "
-                                  "Got value {value}".format(value=value_token.value),
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Expected a quoted string value for attributes. "
+                "Got value {value}".format(value=value_token.value),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         comp = {
             "key": key,
             "comparator": stripped_comparison[1].value,
-            "value": cls._strip_quotes(value_token.value, expect_quoted_value=True)
+            "value": cls._strip_quotes(value_token.value, expect_quoted_value=True),
         }
         return comp
 
@@ -533,35 +591,43 @@ class SearchUtils(object):
         try:
             parsed = sqlparse.parse(filter_string)
         except Exception:
-            raise MlflowException("Error while parsing filter '%s'. %s" % (filter_string, expected),
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Error while parsing filter '%s'. %s" % (filter_string, expected),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         if len(parsed) == 0 or not isinstance(parsed[0], Statement):
-            raise MlflowException("Invalid filter '%s'. Could not be parsed. %s" %
-                                  (filter_string, expected), error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Invalid filter '%s'. Could not be parsed. %s" % (filter_string, expected),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         elif len(parsed) > 1:
-            raise MlflowException("Search filter '%s' contains multiple expressions. "
-                                  "%s " % (filter_string, expected),
-                                  error_code=INVALID_PARAMETER_VALUE)
+            raise MlflowException(
+                "Search filter '%s' contains multiple expressions. "
+                "%s " % (filter_string, expected),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
         statement = parsed[0]
         invalids = list(filter(cls._invalid_statement_token, statement.tokens))
         if len(invalids) > 0:
             invalid_clauses = ", ".join("'%s'" % token for token in invalids)
-            raise MlflowException("Invalid clause(s) in filter string: %s. "
-                                  "%s" % (invalid_clauses, expected),
-                                  error_code=INVALID_PARAMETER_VALUE)
-        return [cls._get_comparison_for_model_registry(
-            si,
-            valid_search_keys)
-            for si in statement.tokens if isinstance(si, Comparison)]
+            raise MlflowException(
+                "Invalid clause(s) in filter string: %s. " "%s" % (invalid_clauses, expected),
+                error_code=INVALID_PARAMETER_VALUE,
+            )
+        return [
+            cls._get_comparison_for_model_registry(si, valid_search_keys)
+            for si in statement.tokens
+            if isinstance(si, Comparison)
+        ]
 
     @classmethod
     def parse_filter_for_model_versions(cls, filter_string):
         return cls._parse_filter_for_model_registry(
-            filter_string,
-            cls.VALID_SEARCH_KEYS_FOR_MODEL_VERSIONS)
+            filter_string, cls.VALID_SEARCH_KEYS_FOR_MODEL_VERSIONS
+        )
 
     @classmethod
     def parse_filter_for_registered_models(cls, filter_string):
         return cls._parse_filter_for_model_registry(
-            filter_string,
-            cls.VALID_SEARCH_KEYS_FOR_REGISTERED_MODELS)
+            filter_string, cls.VALID_SEARCH_KEYS_FOR_REGISTERED_MODELS
+        )
